@@ -353,7 +353,7 @@ def elevationBinPlot3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2, x_s
     else:
     	plt.show()
 
-def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, colorbarMax=None, savefig=False):
+def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, colorbarMin=None, colorbarMean=None, colorbarMax=None, savefig=False):
     '''
     Plots a map from input values (array-like)
     :param dataVals: values to be plotted
@@ -368,10 +368,18 @@ def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, c
     fig = plt.figure()
     ax = fig.add_subplot(111, label="1")
 
+    vmin = dataVals.min()
+    vmean = dataVals.mean()
+    vmax = dataVals.max()
+    
+    if colorbarMin != None:
+        vmin = colorbarMin
+    if colorbarMean != None:
+        vmean = colorbarMean
     if colorbarMax != None:
-        divnorm = TwoSlopeNorm(vmin=dataVals.min(), vcenter=colorbarMax/2, vmax=colorbarMax)
-    else:
-        divnorm = TwoSlopeNorm(vmin=dataVals.min(), vcenter=dataVals.mean(), vmax=dataVals.max())
+        vmax = colorbarMax
+    
+    divnorm = TwoSlopeNorm(vmin=vmin, vcenter=vmean, vmax=vmax)
     dataVals = dataVals.astype(float)
     dataVals[dataVals == 0] = np.nan                                  # to remove 0 values for white background in plot
     im = ax.imshow(dataVals, cmap=plt.cm.get_cmap(color, cluster), norm=divnorm) #check len datavals
